@@ -2,4 +2,6 @@ from .centerinfo import *
 from .hand import *
 from .meld import *
 from .discard import *
-from .dora import *
\ No newline at end of file
+from .dora import *
+from .scorescreen import *
+from .opponenticons import *
\ No newline at end of file
